@@ -10,7 +10,7 @@
 # copyright at the end of the file in the pod section
 
 package Config::Model::TkUI;
-$Config::Model::TkUI::VERSION = '1.358';
+$Config::Model::TkUI::VERSION = '1.359';
 use 5.10.1;
 use strict;
 use warnings;
@@ -772,8 +772,12 @@ sub disp_obj_elt {
 sub show_single_list_value {
     my ($cw, $tkt, $obj, $path, $show) = @_;
     my $elt_type = $obj->get_type;
+
+    # leave alone element that is not a list of leaf
+    return unless $elt_type eq 'list' and $obj->get_cargo_type eq 'leaf';
+
     $logger->trace("show_single_list_value called on ", $obj->location);
-    if ($elt_type eq 'list' and $obj->get_cargo_type eq 'leaf' and $obj->fetch_size == 1 and $show) {
+    if ($obj->fetch_size == 1 and $show) {
         disp_leaf(undef,[ $path, $cw ], $obj->parent, $obj->element_name, 0, $obj->fetch_with_id(0));
     }
     else {
